baseObjects.Session

|  | ## Cheshire3 Object Model: Class Session

Module baseObjects :: Class Session

## Class Session
source code

An object to be passed around amongst the processing objects to maintain a session. It stores, for example, the current environment, user and identifier for the database.
Class Variables

user |
task |
database |
environment |

Class Variable Details

    ### user Value:
        None

    ### task Value:
        ''

    ### database Value:
        ''

    ### environment Value:
        ''